Package {actiwalkability}


Type: Package
Title: Access the EPA Walkability Index
Version: 0.1.0
Description: Provides helpers for querying the EPA Walkability Index https://www.epa.gov/smartgrowth/national-walkability-index-user-guide-and-methodology and working with Census GEOID/FIPS identifiers https://www.census.gov/programs-surveys/geography/guidance/geo-identifiers.html.
License: GPL-3
Depends: R (≥ 4.1.0)
Suggests: covr, ggplot2, ggrepel, knitr, withr, testthat, rmarkdown, curl
Encoding: UTF-8
VignetteBuilder: knitr
Imports: arcgislayers, assertthat, dplyr, rlang
Config/roxygen2/version: 8.0.0
URL: https://github.com/jhuwit/actiwalkability, https://jhuwit.github.io/actiwalkability/
BugReports: https://github.com/jhuwit/actiwalkability/issues
NeedsCompilation: no
Packaged: 2026-08-26 01:35:28 UTC; johnmuschelli
Author: John Muschelli ORCID iD [aut, cre]
Maintainer: John Muschelli <muschellij2@gmail.com>
Repository: CRAN
Date/Publication: 2026-09-08 13:20:09 UTC

Get EPA Walkability Index

Description

Get EPA Walkability Index

Usage

acti_epa_walkability(geoid, geometry = TRUE, ...)

Arguments

geoid

GEOID10 of the area of interest. This should be a 12 character string. If NULL, then all GEOIDs are selected. This can be a lot of data, so use with caution.

geometry

Should geometry be returned? Passed to arcgislayers::arc_select()

...

Additional arguments to pass to arcgislayers::arc_select()

Value

A data.frame of results.

Note

See https://geodata.epa.gov/arcgis/rest/services/OA/WalkabilityIndex/MapServer/0

Examples


acti_epa_walkability(c("240054519002", "240054026041", "245102303002"), geometry = FALSE)


Get EPA Walkability Index layer metadata

Description

Opens the EPA Walkability Index ArcGIS layer and returns its metadata. This includes the available fields, layer extent, geometry type, and service limits such as maxRecordCount.

Usage

acti_epa_walkability_metadata()

Value

A FeatureLayer object, which is a list containing the ArcGIS layer metadata.

Note

See https://geodata.epa.gov/arcgis/rest/services/OA/WalkabilityIndex/MapServer/0

Examples

## Not run: 
metadata <- acti_epa_walkability_metadata()
metadata$fields

## End(Not run)

Get Census Tract FIPS codes

Description

Get Census Tract FIPS codes

Usage

acti_fips15(state, county, tract, block = NA)

acti_fips12(state, county, tract, block = NA)

Arguments

state

2-digit state FIPS code.

county

3-digit county FIPS code.

tract

6-digit tract FIPS code.

block

4-digit block FIPS code. If omitted or NA, tract-level codes are returned.

Value

An 11-to-15 digit GEOID/FIPS code.

Examples

suppressWarnings(acti_fips15(24, 510, 60400))
acti_fips15(24, 510, 60400, block = 2002)
acti_fips12(24, 510, 60400, block = 2002)

Open the EPA Walkability Index layer

Description

Open the EPA Walkability Index layer

Usage

epa_arc()